Container/Module/theme/inherited_neumorphic_theme library
Classes
- LightSource
- NeumorphicBorder
- NeumorphicColors
- Defines default colors used in Neumorphic theme & shadows generators
- NeumorphicStyle
- NeumorphicThemeData
- NeumorphicThemeInherited
- ThemeWrapper
- A immutable contained by the NeumorhicTheme That will save the current definition of the theme It will be accessible to the childs widgets by an InheritedWidget
Enums
Constants
Typedefs
- NeumorphicThemeUpdater = NeumorphicThemeData Function(NeumorphicThemeData? current)