NeumorphicRadioStyle class
Constructors
- NeumorphicRadioStyle({double? selectedDepth, double? unselectedDepth, Color? selectedColor, Color? unselectedColor, LightSource? lightSource, bool disableDepth = false, NeumorphicBoxShape? boxShape, NeumorphicBorder border = const NeumorphicBorder.none(), double? intensity, NeumorphicShape? shape})
-
const
Properties
- border → NeumorphicBorder
-
final
- boxShape → NeumorphicBoxShape?
-
final
- disableDepth → bool
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- intensity → double?
-
final
- lightSource → LightSource?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedColor → Color?
-
final
- selectedDepth → double?
-
final
- shape → NeumorphicShape?
-
final
- unselectedColor → Color?
-
final
- unselectedDepth → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override